@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Local
 #include "kpimtextedit/slidecontainer.h"
 
-#include <qtest.h>
+#include <QTest>
 #include <QTextEdit>
 #include <QVBoxLayout>
 #include <QSignalSpy>
