@@ -57,6 +57,8 @@ void EmoticonUnicodeTab::loadEmoticons()
         createPlainTextEmoticonTab(QString(), TextUtils::unicodeFantasyEmoji());
         createPlainTextEmoticonTab(QString(), TextUtils::unicodePlantEmoji());
         createPlainTextEmoticonTab(QString(), TextUtils::unicodeTravelEmoji());
+        createPlainTextEmoticonTab(QString(), TextUtils::unicodeBookPaperEmoji());
+        createPlainTextEmoticonTab(QString(), TextUtils::unicodeBookToolsEmoji());
     } else {
         createHtmlEmoticonTab();
     }
