@@ -32,12 +32,18 @@ public:
     explicit EmoticonUnicodeTab(QWidget *parent = nullptr);
     ~EmoticonUnicodeTab();
 
+    Q_REQUIRED_RESULT bool emojiPlainText() const;
+    void setEmojiPlainText(bool emojiPlainText);
+
+    void loadEmoticons();
+
 Q_SIGNALS:
     void itemSelected(const QString &);
 
 private:
-    void loadEmoticons();
-    void createTab(const QString &str, const QList<uint> &emoticons);
+    void createPlainTextEmoticonTab(const QString &str, const QList<uint> &emoticons);
+    void createHtmlEmoticonTab();
+    bool mEmojiPlainText = true;
 };
 }
 
